==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Offset</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Escolha linha, arco ou círculo</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Para&amp;lelas (com a distância)</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Offset (com Distância)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Offset de linha, arco, círculo ou elipse</translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Desenhe uma paralela à linha existente, ou arco ou círculo concêntrico</translation>
    </message>
    <message>
        <source>Distance:</source>
        <translatorcomment>--exact match--
--file: CircleConcentric_pt.ts--
Distância: %1
Selecione a entidade a ser aparada ou entre a distância:</translatorcomment>
        <translation type="obsolete">Distância:</translation>
    </message>
    <message>
        <source>Number:</source>
        <translatorcomment>--exact match--
--file: CircleConcentricThrough_pt.ts--
Entre o número:
Número:</translatorcomment>
        <translation type="obsolete">Número:</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Distância:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Número:</translation>
    </message>
    <message>
        <source>Choose line, arc, circle, ellipse or spline</source>
        <translation type="vanished">Escolha uma linha, arco, círculo ou elipse</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Escolha uma linha, arco, círculo ou elipse</translation>
    </message>
    <message>
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation>O Raio ficou abaixo de 0,0, após %1 círculo(s) concêntrico(s).</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation>O Raio ficou abaixo de 0,0, após %1 arco(s) concêntrico(s).</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Offset</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Escolha linha, arco ou círculo</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Para&amp;lelas (com a distância)</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Offset (com Distância)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Offset de linha, arco, círculo ou elipse</translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Desenhe uma paralela à linha existente, ou arco ou círculo concêntrico</translation>
    </message>
    <message>
        <source>Distance:</source>
        <translatorcomment>--exact match--
--file: CircleConcentric_pt.ts--
Distância: %1
Selecione a entidade a ser aparada ou entre a distância:</translatorcomment>
        <translation type="obsolete">Distância:</translation>
    </message>
    <message>
        <source>Number:</source>
        <translatorcomment>--exact match--
--file: CircleConcentricThrough_pt.ts--
Entre o número:
Número:</translatorcomment>
        <translation type="obsolete">Número:</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Distância:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Número:</translation>
    </message>
    <message>
        <source>Choose line, arc, circle, ellipse or spline</source>
        <translation type="vanished">Escolha uma linha, arco, círculo ou elipse</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Escolha uma linha, arco, círculo ou elipse</translation>
    </message>
    <message numerus="yes">
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %n concentric circle(s).</source>
        <translation>
            <numerusform>O Raio ficou abaixo de 0,0, após %n círculo concêntrico.</numerusform>
            <numerusform>O Raio ficou abaixo de 0,0, após %n círculos concêntricos.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %n concentric arc(s).</source>
        <translation>
            <numerusform>O Raio ficou abaixo de 0,0, após %n arco concêntrico.</numerusform>
            <numerusform>O Raio ficou abaixo de 0,0, após %n arcos concêntricos.</numerusform>
        </translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">O Raio ficou abaixo de 0,0, após %1 círculo(s) concêntrico(s).</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">O Raio ficou abaixo de 0,0, após %1 arco(s) concêntrico(s).</translation>
    </message>
</context>
</TS>
